@@ -1,8 +1,11 @@
+import Control.Concurrent (threadDelay)
 import Control.Exception (finally)
 import Control.Monad (forever)
+import Data.Bifunctor (first)
+import Data.Semigroup (Max(getMax))
+import XNobar.Internal.Positive32 (Positive32(toWord32))
 import XNobar.Internal.Scroller () -- import Show instance for XNobar.Internal.Notification.Notification
 import XNobar.Server (fetch, startServer)
-import Control.Concurrent (threadDelay)
 
 main :: IO ()
 main = do
@@ -13,4 +16,4 @@ main = do
                           forever $ do
                             ns <- fetch notifs
                             threadDelay 100000
-                            print $ show . snd <$> ns
+                            print $ first (getMax . toWord32) <$> ns
